summaryrefslogtreecommitdiffstats
path: root/chrome/browser/tab_contents/tab_contents.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/tab_contents/tab_contents.h')
-rw-r--r--chrome/browser/tab_contents/tab_contents.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/chrome/browser/tab_contents/tab_contents.h b/chrome/browser/tab_contents/tab_contents.h
index cf25aba..3b749e6 100644
--- a/chrome/browser/tab_contents/tab_contents.h
+++ b/chrome/browser/tab_contents/tab_contents.h
@@ -415,8 +415,9 @@ class TabContents : public PageNavigator,
// Displays the download shelf and animation when a download occurs.
void OnStartDownload(DownloadItem* download);
- // Returns the DownloadShelf, creating it if necessary.
- DownloadShelf* GetDownloadShelf();
+ // Returns the DownloadShelf. If the shelf doesn't exist and |create| is true,
+ // this function will create the shelf.
+ DownloadShelf* GetDownloadShelf(bool create);
// Transfer the shelf view from |tab_contents| to the receiving TabContents.
// |tab_contents| no longer owns the shelf after this call. The shelf is owned